import { GoClock } from "react-icons/go";
import { PiMapPinLight, PiInfo, PiCalendarCheck } from "react-icons/pi";
import React, { useEffect, useState } from 'react'
import Link from "next/link";
import { format } from "date-fns";
import TimeDateSelection from "./TimeDateSelection";

const MeetingEventSelection = ({meetingEventInfo, businessInfo}) => {
    const [date, setDate] = useState(new Date());
    const [timeSlots, setTimeSlots] = useState();
    const [unavialableTime, setUnavialableTime] = useState(false)
    const [selectedTime, setSelectedTime] = useState();

    useEffect(() => {
        meetingEventInfo?.timeDuration && createTimeSlot(meetingEventInfo?.timeDuration)
    }, [meetingEventInfo])
    //create time slot
    const createTimeSlot = (interval) => {
        const startTime = 8 * 60;
        const endTime = 22 * 60;
        const totalSlots = (endTime - startTime) / interval;
        const slots = Array.from({length: totalSlots}, (_, i) => {
            const totalMinutes = startTime + i * interval;
            const hours = Math.floor(totalMinutes / 60);
            const minutes = totalMinutes % 60;
            const formattedHours = hours > 12 ? hours - 12: hours;
            const period = hours >= 12? 'PM' : 'AM';
            return `${String(formattedHours).padStart(2, '0')} : ${String(minutes).padStart(2, '0')} ${period}`
        });
        setTimeSlots(slots);
    }

    const handleDatechange = (date) => {
        setDate(date);
        const day = format(date, 'EEEE')
        if(businessInfo?.availableDays?.[day]){
            setUnavialableTime(true)
        } else {
            setUnavialableTime(false)
        }
    }
    

    return (
    <div className='px-5 py-10 shadow-md m-4 border-t-8 mx-10 md:mx-20 lg:mx-40 my-10 xl:mx-60 lg:my-20' style={{borderTopColor: meetingEventInfo?.themeColor}}>
        <p className='text-xl uppercase font-semibold tracking-wide'>Schedule.Me</p>
        <div className='grid grid-cols-1 lg:grid-cols-3 mt-5'>
            <div className='border-r'>
                <p className='font-semibold mb-5 text-xl'>{businessInfo?.businessName}</p>
                <p className="font-normal flex items-center gap-1"><PiInfo/> {meetingEventInfo?.eventName?meetingEventInfo?.eventName:'Meeting/Event Name'}</p>
                <div className='mt-2 flex flex-col gap-2'>
                    <p className='flex gap-1 items-center'><PiCalendarCheck/>{format(date, 'PPP')}</p>
                    <p className='flex gap-1 items-center'><GoClock/>{meetingEventInfo?.timeDuration} minutes {selectedTime && <span className="text-sm text-gray-500">({selectedTime})</span>}</p>
                    <p className='flex gap-1 items-center'><PiMapPinLight/>{meetingEventInfo?.locationMeeting}</p>
                    <Link href={meetingEventInfo?.urlMeeting?meetingEventInfo?.urlMeeting:''} className="text-gray-500 underline text-sm">{meetingEventInfo?.urlMeeting}</Link>
                </div>
            </div>
            <TimeDateSelection date={date} unavialableTime={unavialableTime} handleDatechange={handleDatechange} setSelectedTime={setSelectedTime} timeSlots={timeSlots}/>
        </div>
    </div>
  )
}

export default MeetingEventSelection